@@ -1,22 +1,11 @@
 from openfisca_core.model_api import *
 from openfisca_us.entities import *
+from openfisca_tools.model_api import *
 import numpy as np
 
 USD = "currency-USD"
 
 
-def add(entity, period, *variables):
-    return sum([entity(var, period) for var in variables])
-
-
-def aggr(entity, period, *variables):
-    return entity.sum(add(entity, period, *variables))
-
-
-def amount_between(x, lower, upper):
-    return max_(min_(x, upper), lower) - lower
-
-
 def tax_unit_non_dep_sum(var, tax_unit, period):
     return tax_unit.sum(
         tax_unit.members(var, period)
