@@ -15,8 +15,8 @@ class snap(Variable):
         # defines state powers to modify the rules.
         eligible = spm_unit("is_snap_eligible", period)
         expected_contribution = spm_unit("snap_expected_contribution", period)
-        max_benefit = spm_unit("snap_max_benefit", period)
-        normal_benefit = max_benefit - expected_contribution
-        min_benefit = spm_unit("snap_minimum_benefit", period)
-        amount_if_eligible = max_(min_benefit, normal_benefit)
-        return eligible * amount_if_eligible
+        max_allotment = spm_unit("snap_max_allotment", period)
+        normal_allotment = max_allotment - expected_contribution
+        min_allotment = spm_unit("snap_min_allotment", period)
+        allotment_if_eligible = max_(min_allotment, normal_allotment)
+        return eligible * allotment_if_eligible
